pub enum DurationResult {
NoEffects,
Infinite,
Finite(i32),
}Expand description
The result of a duration calculation for a status effect.
Variants
NoEffects
There are no effects of the given type.
Infinite
The effect has an infinite duration.
Finite(i32)
The effect has a finite duration, represented as an integer number of ticks.