pub struct ActiveStatusEffects { /* private fields */ }Expand description
[Component] that stores the ActiveStatusEffects of an [Entity].
Implementations
Sourceimpl ActiveStatusEffects
impl ActiveStatusEffects
Sourcepub fn apply(&mut self, effect: ActiveStatusEffect)
pub fn apply(&mut self, effect: ActiveStatusEffect)
Applies a new ActiveStatusEffect.
If the ActiveStatusEffect is already active:
- if the new effect is the same as the old one and its duration is longer, it replaces the old effect. Otherwise, it does nothing.
- if the new effect is stronger than the old one:
- if the new effect’s duration is longer, it replaces the old effect.
- if the new effect’s duration is shorter, it overrides the old
- if the new effect is weaker than the old one and if the new effect’s duration is longer, it will be overridden by the old effect until the old effect’s duration is over.
Sourcepub fn replace(&mut self, effect: ActiveStatusEffect)
pub fn replace(&mut self, effect: ActiveStatusEffect)
Replace an existing ActiveStatusEffect.
Sourcepub fn remove(&mut self, effect: StatusEffect)
pub fn remove(&mut self, effect: StatusEffect)
Removes an ActiveStatusEffect.
Sourcepub fn remove_all(&mut self)
pub fn remove_all(&mut self)
Removes all ActiveStatusEffects.
Sourcepub fn no_effect(&self, effect: StatusEffect) -> bool
pub fn no_effect(&self, effect: StatusEffect) -> bool
Returns true if there are no effects of the given type.
Sourcepub fn has_effect(&self, effect: StatusEffect) -> bool
pub fn has_effect(&self, effect: StatusEffect) -> bool
Returns true if there is an effect of the given type.
Sourcepub fn no_effects(&self) -> bool
pub fn no_effects(&self) -> bool
Returns true if there are no effects.
Sourcepub fn has_effects(&self) -> bool
pub fn has_effects(&self) -> bool
Returns true if there are any effects.
Sourcepub fn max_duration(&self, effect: StatusEffect) -> DurationResult
pub fn max_duration(&self, effect: StatusEffect) -> DurationResult
Returns the maximum duration of the given effect.
Sourcepub fn get_current_effect(
&self,
effect: StatusEffect,
) -> Option<&ActiveStatusEffect>
pub fn get_current_effect( &self, effect: StatusEffect, ) -> Option<&ActiveStatusEffect>
Gets the current effect of the given type.
Sourcepub fn get_all_effect(
&self,
effect: StatusEffect,
) -> Option<&Vec<ActiveStatusEffect>>
pub fn get_all_effect( &self, effect: StatusEffect, ) -> Option<&Vec<ActiveStatusEffect>>
Gets all the effects of the given type.
Sourcepub fn get_current_effects(&self) -> Vec<&ActiveStatusEffect>
pub fn get_current_effects(&self) -> Vec<&ActiveStatusEffect>
Gets all the current effects.
Sourcepub fn get_all_effects(
&self,
) -> &IndexMap<StatusEffect, Vec<ActiveStatusEffect>>
pub fn get_all_effects( &self, ) -> &IndexMap<StatusEffect, Vec<ActiveStatusEffect>>
Gets all the effects.